SystemOrganization addCategory: #'STON-Tests'!

TestCase subclass: #STONCStyleCommentsSkipStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONCStyleCommentsSkipStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 7/17/2015 14:15'!
testCommentInString
	self 
		assert: (STONCStyleCommentsSkipStream on: '''/*comment*/''' readStream) upToEnd 
		equals: '''/*comment*/'''.
	self 
		assert: (STONCStyleCommentsSkipStream on: '{''foo'':''/*comment*/bar''}' readStream) upToEnd 
		equals: '{''foo'':''/*comment*/bar''}'.
	self 
		assert: (STONCStyleCommentsSkipStream on: '{''foo'':''//comment\''bar''}' readStream) upToEnd 
		equals: '{''foo'':''//comment\''bar''}'.
	self 
		assert: (STONCStyleCommentsSkipStream on: '{"foo":"/*comment*/bar"}' readStream) upToEnd 
		equals: '{"foo":"/*comment*/bar"}'.
	self 
		assert: (STONCStyleCommentsSkipStream on: '{"foo":"//comment\"bar"}' readStream) upToEnd 
		equals: '{"foo":"//comment\"bar"}'! !

!STONCStyleCommentsSkipStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 7/17/2015 13:38'!
testMultiLineComment
	self 
		assert: (STONCStyleCommentsSkipStream on: 'foo\//comment\bar' withCRs readStream) upToEnd 
		equals: 'foo\bar' withCRs.
	self 
		assert: (STONCStyleCommentsSkipStream on: 'foo\//comment\bar' withCRs readStream) nextLine
		equals: 'foo'.
	self 
		assert: ((STONCStyleCommentsSkipStream on: 'foo\//comment\bar' withCRs readStream) nextLine; nextLine) 
		equals: 'bar'.
	self assert: (STONCStyleCommentsSkipStream on: '//comment' readStream) atEnd.! !

!STONCStyleCommentsSkipStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/8/2015 23:17'!
testNonComment
	self assert: (STONCStyleCommentsSkipStream on: 'foo' readStream) upToEnd equals: 'foo'.
	self assert: (STONCStyleCommentsSkipStream on: 'foo' readStream) nextLine equals: 'foo'.
	self deny: (STONCStyleCommentsSkipStream on: 'foo' readStream) atEnd.
	self assert: (STONCStyleCommentsSkipStream on: '' readStream) atEnd.! !

!STONCStyleCommentsSkipStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 7/17/2015 14:16'!
testSTON
	"Comments are processed first and totally removed.
	They are not even whitespace (not that whitespace is relevant in STON)."
	
	self 
		assert: (STON fromStream: (STONCStyleCommentsSkipStream on: '123/*comment*/456' readStream)) 
		equals: 123456.
	self 
		assert: (STON fromStream: (STONCStyleCommentsSkipStream on: '/*comment*/''abcd''' readStream)) 
		equals: 'abcd'.
	self 
		assert: (STON fromStream: (STONCStyleCommentsSkipStream on: '123//456' readStream)) 
		equals: 123.
	self 
		should: [ STON fromStream: (STONCStyleCommentsSkipStream on: '//456' readStream) ] 
		raise: STONReaderError
! !

!STONCStyleCommentsSkipStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 7/17/2015 13:39'!
testSingleLineComment
	self assert: (STONCStyleCommentsSkipStream on: 'foo/*comment*/bar' readStream) upToEnd equals: 'foobar'.
	self assert: (STONCStyleCommentsSkipStream on: 'foo/*comment*/bar' readStream) nextLine equals: 'foobar'.
	self deny: (STONCStyleCommentsSkipStream on: 'foo/*comment*/bar' readStream) atEnd.
	self assert: (STONCStyleCommentsSkipStream on: '/*comment*/' readStream) atEnd.! !

TestCase subclass: #STONJSONTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONJSONTests commentStamp: 'SvenVanCaekenberghe 3/15/2016 14:42' prior: 0!
STONJSONTests contains unit tests for the JSON functionality available in STON.!

!STONJSONTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 3/15/2016 14:44'!
testBooleans
	self assert: (STONJSON toString: true) equals: 'true'.
	self assert: (STONJSON toString: false) equals: 'false'.
	self assert: (STONJSON fromString: 'true') equals: true.
	self assert: (STONJSON fromString: 'false') equals: false.! !

!STONJSONTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 3/15/2016 16:46'!
testCircular
	"Circular datastructures cannot be encoded using JSON"
	self
		should: [ | foo |
			foo := { 'foo'->'dummy' } asDictionary.
			foo at: 'bar' put: foo.
			STONJSON toString: foo ]
		raise: STONWriterError! !

!STONJSONTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 3/15/2016 14:55'!
testFloats
	self assert: (STONJSON toString: 1.0) equals: '1.0'.
	self assert: (STONJSON toString: 0.0) equals: '0.0'.
	self assert: (STONJSON toString: -1.0) equals: '-1.0'.
	self assert: (STONJSON toString: -1.23456e-6) equals: '-1.23456e-6'.
	self assert: ((STONJSON fromString: '1.0') closeTo: 1.0).
	self assert: ((STONJSON fromString: '0.0') closeTo: 0.0).
	self assert: ((STONJSON fromString: '-1.0') closeTo: -1.0).
	self assert: ((STONJSON fromString: '-1.23456e-6') closeTo: -1.23456e-6).! !

!STONJSONTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 3/15/2016 14:51'!
testIntegers
	self assert: (STONJSON toString: 1) equals: '1'.
	self assert: (STONJSON toString: 0) equals: '0'.
	self assert: (STONJSON toString: -1) equals: '-1'.
	self assert: (STONJSON toString: 1234567890) equals: '1234567890'.
	self assert: (STONJSON fromString: '1') equals: 1.
	self assert: (STONJSON fromString: '0') equals: 0.
	self assert: (STONJSON fromString: '-1') equals: -1.
	self assert: (STONJSON fromString: '1234567890') equals: 1234567890.! !

!STONJSONTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 3/15/2016 14:59'!
testLists
	self assert: (STONJSON toString: #(1 2 3)) equals: '[1,2,3]'.
	self assert: (STONJSON toString: #(1 -2 true 3 nil)) equals: '[1,-2,true,3,null]'.
	self assert: (STONJSON toString: #(1 (2) 3)) equals: '[1,[2],3]'.
	self assert: (STONJSON toString: #()) equals: '[]'.
	self assert: (STONJSON fromString: '[]') equals: #().
	self assert: (STONJSON fromString: '[1,2,3]') equals: #(1 2 3).
	self assert: (STONJSON fromString: '[1,-2,true,3,null]') equals: #(1 -2 true 3 nil).
	self assert: (STONJSON fromString: '[1,[2],3]') equals: #(1 (2) 3).! !

!STONJSONTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 3/15/2016 15:05'!
testMaps
	self assert: (STONJSON toString: { 'temperature'->37 } asDictionary) equals: '{"temperature":37}'.
	self assert: (STONJSON toString: Dictionary new) equals: '{}'.
	self assert: (STONJSON fromString: '{"temperature":37}') equals: { 'temperature'->37 } asDictionary.
	self assert: (STONJSON fromString: '{}') equals: Dictionary new.! !

!STONJSONTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 3/15/2016 14:52'!
testNull
	self assert: (STONJSON toString: nil) equals: 'null'.
	self assert: (STONJSON fromString: 'null') equals: nil.! !

!STONJSONTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 3/15/2016 16:47'!
testShared
	"Structure sharing cannot be encoded using JSON"
	self
		should: [ | foo |
			foo := { 'foo'->'dummy' } asDictionary.
			STONJSON toString: { foo. foo } ]
		raise: STONWriterError! !

!STONJSONTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 3/15/2016 17:04'!
testStrings
	self assert: (STONJSON toString: 'string') equals: '"string"'.
	self assert: (STONJSON toString: '') equals: '""'.
	self assert: (STONJSON toString: 'élèves français') equals: '"élèves français"'.
	self assert: (STONJSON toString: String crlf) equals: '"\r\n"'.
	self assert: (STONJSON fromString: '"string"') equals: 'string'.
	self assert: (STONJSON fromString: '""') equals: ''.
	self assert: (STONJSON fromString: '"élèves français"') equals: 'élèves français'.
	self 
		assert: (STONJSON fromString: '"\u212B \"Angstrom Symbol\""') 
		equals: 8491 asCharacter asString, ' "Angstrom Symbol"'.! !

!STONJSONTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 3/15/2016 16:48'!
testUnknown
	"Only Array for lists and Dictionary for maps are allowed for JSON encoding,
	any other Smalltalk object cannot be encoded (following the specs).
	Even considering all collections to be lists won't work because the type 
	is then lost when decoding"
	
	self should: [ STONJSON toString: 1@2 ] raise: STONWriterError.
	self should: [ STONJSON toString: #(1 2 3) asOrderedCollection ] raise: STONWriterError.! !

TestCase subclass: #STONReaderTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONReaderTests commentStamp: 'SvenVanCaekenberghe 1/22/2012 20:14' prior: 0!
STONReaderTests test materialization.
!

!STONReaderTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/5/2012 20:02'!
materialize: string
	^ STON reader 
		on: string readStream;
		next! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 11/27/2014 10:57'!
testAssociation
	self assert: (self materialize: '''foo'':1') = ('foo' -> 1).
	self assert: (self materialize: '#bar:2') = (#bar -> 2).
	self assert: (self materialize: '''foo bar'':#ok') = ('foo bar' -> #ok).
	self assert: (self materialize: '123:456') = (123 -> 456).
	
	self assert: (self materialize: '''foo'' : 1') = ('foo' -> 1).
	self assert: (self materialize: '#bar : 2') = (#bar -> 2).
	self assert: (self materialize: '''foo bar'' : #ok') = ('foo bar' -> #ok).
	self assert: (self materialize: '123 : -456') = (123 -> -456).
	
	self assert: (self materialize: '#foo : 1 : 2') = (#foo -> (1 -> 2))
! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/28/2015 14:22'!
testBoolean
	self assert: (self materialize: 'true') equals: true.
	self assert: (self materialize: 'false') equals: false! !

!STONReaderTests methodsFor: 'tests' stamp: 'dkh 4/29/2012 08:48:15'!
testByteArray
	self assert: (self materialize: 'ByteArray[''010203'']') = #(1 2 3) asByteArray
! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/18/2012 20:44'!
testCharacter
	self assert: (self materialize: 'Character[''A'']') == $A.! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 12/23/2015 19:25'!
testClass
	self assert: (self materialize: 'Class[#Point]') equals: Point! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/26/2015 23:03'!
testConvertingNewLines
	| input result output |
	input := '''line ending with CR', String cr, 
		'line ending with LF', String lf, 
		'line ending with CRLF', String crlf, ''''.
	output := 'line ending with CR', String crlf, 
		'line ending with LF', String crlf, 
		'line ending with CRLF', String crlf.
	result := (STON reader on: input readStream) newLine: String crlf; convertNewLines: true; next.
	self assert: result equals: output.
	output := 'line ending with CR', String cr, 
		'line ending with LF', String cr, 
		'line ending with CRLF', String cr.
	result := (STON reader on: input readStream) newLine: String cr; convertNewLines: true; next.
	self assert: result equals: output! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/23/2012 09:37'!
testDate
	| date |
	date := Date year: 2012 month: 1 day: 1.
	self assert: (self materialize: 'Date[''2012-01-01'']') = date! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/19/2012 10:01'!
testDateAndTime
	| dateAndTime |
	dateAndTime := DateAndTime year: 2012 month: 1 day: 1 hour: 6 minute: 30 second: 15 offset: 1 hour.
	self assert: (self materialize: 'DateAndTime[''2012-01-01T06:30:15+01:00'']') = dateAndTime! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/6/2016 13:37'!
testDeepStructure
	| holder deepest structure writer ston reader result |
	"Create a deep nested structure so that the deepest element is a reference back to a top level holder."
	holder := Array with: 42.
	deepest := Array with: holder.
	structure := deepest.
	64 * 1024 timesRepeat: [ structure := Array with: structure ].
	structure := Array with: holder with: structure.
	writer := STON writer optimizeForLargeStructures.
	ston := String streamContents: [ :out | (writer on: out) nextPut: structure ].
	"After reading, the second pass will have to go down the structure to resolve the reference."
	reader := STON reader optimizeForLargeStructures.
	result := (reader on: ston readStream) next.
	self assert: result equals: structure! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/5/2012 20:09'!
testDictionary
	| collection |
	collection := STON mapClass new at: 1 put: 1; at: 2 put: 2; yourself.
	self assert: (self materialize: '{1:1,2:2}') = collection.
	self assert: (self materialize: '{}') = STON mapClass new.
! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 10/24/2016 10:28'!
testDictionaryWithComplexKeys
	| collection reader |
	collection := STON mapClass new at: true put: 1; at: #(foo) put: 2; yourself.
	"allowing complex map keys used to be optional, now it is always the default"
	reader := STONReader on: '{true:1,[#foo]:2}' readStream.
	self assert: reader next = collection! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 10/24/2016 10:28'!
testDictionaryWithIndirectReferenceKeys
	| keysCollection dictionary ston object |
	keysCollection := OrderedCollection streamContents: [ :out |
		10 timesRepeat: [ out nextPut: UUID new ] ].
	dictionary := Dictionary new.
	keysCollection doWithIndex: [ :each :index | 
		dictionary at: (Array with: each) put: index ].
	object := Array with: keysCollection with: dictionary.
	ston := STON toStringPretty: object.
	object := (STON reader on: ston readStream) next.
	object first doWithIndex: [ :each :index |
		self assert: (object second at: (Array with: each)) equals: index ].
	self assert: object second isHealthy ! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 10/24/2016 10:28'!
testDictionaryWithReferenceKeys
	| keysCollection dictionary ston object |
	keysCollection := OrderedCollection streamContents: [ :out |
		10 timesRepeat: [ out nextPut: UUID new ] ].
	dictionary := Dictionary new.
	keysCollection doWithIndex: [ :each :index | 
		dictionary at: each put: index ].
	object := Array with: keysCollection with: dictionary.
	ston := STON toStringPretty: object.
	object := (STON reader on: ston readStream) next.
	object first doWithIndex: [ :each :index |
		self assert: (object second at: each) equals: index ].
	self assert: object second isHealthy ! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/7/2012 13:25'!
testError
	#( 'foo' '{foo:}' '{foo,}' '[1,]' '+1' ']' '#' '' '  ' '	' 'nul' 'tru' 'fals' ) do: [ :each |
		self 
			should: [ self materialize: each ] 
			raise: STONReaderError ]
! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/28/2015 14:42'!
testFloat
	self assert: ((self materialize: '1.5') closeTo: 1.5).
	self assert: ((self materialize: '-1.5') closeTo: -1.5).
	self assert: (self materialize: '0.0') isZero.
	self assert: (Float pi closeTo: (self materialize: '3.14149')).
	self assert: (1/3 closeTo: (self materialize: '0.333333')).
	self assert: ((self materialize: '1.0e100') closeTo: (10 raisedTo: 100)).
	self assert: ((self materialize: '1.0e-100') closeTo: (10 raisedTo: -100)).
	self assert: ((self materialize: '-1.0e-100') closeTo: (10 raisedTo: -100) negated)! !

!STONReaderTests methodsFor: 'tests' stamp: 'dkh 4/29/2012 08:48:15'!
testIdentityDictionary
	| collection |
	collection := IdentityDictionary new at: 1 put: 1; at: 2 put: 2; yourself.
	self assert: (self materialize: 'IdentityDictionary{1:1,2:2}') = collection.
	self assert: (self materialize: 'IdentityDictionary{}') = IdentityDictionary new.
! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/26/2015 23:33'!
testIllegalCharacterEscapes
	self should: [ STON fromString: '''\a''' ] raise: STONReaderError.
	self should: [ STON fromString: '''\u''' ] raise: STONReaderError.
	self should: [ STON fromString: '''\u00''' ] raise: STONReaderError.
	self should: [ STON fromString: '''\u000''' ] raise: STONReaderError.
	self should: [ STON fromString: '''\*''' ] raise: STONReaderError! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/15/2012 09:21'!
testInteger
	self assert: (self materialize: '1') = 1.
	self assert: (self materialize: '-1') = -1.
	self assert: (self materialize: '0') = 0.
	self assert: (self materialize: '1234567890') = 1234567890.
	self assert: (self materialize: '-1234567890') = -1234567890! !

!STONReaderTests methodsFor: 'tests' stamp: 'dkh 4/29/2012 08:48:15'!
testJsonString
	"Allow double quotes for backwards JSON compatibility"
	
	| string |
	self assert: (self materialize: '"foo"') = 'foo'.
	self assert: (self materialize: '"FOO"') = 'FOO'.
	self assert: (self materialize: '"\u00E9l\u00E8ve en Fran\u00E7ais"') = 'élève en Français'.
	string := String withAll: { 
		$". $'. $\. Character tab. Character cr. Character lf.  Character newPage. Character backspace }.
	self assert: (self materialize: '"\"\''\\\t\r\n\f\b"') = string.
! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/28/2015 14:46'!
testList
	self assert: STON listClass = Array.
	self assert: (self materialize: '[1,2,3]') = (STON listClass with: 1 with: 2 with: 3).
	self assert: (self materialize: '[]') = STON listClass new! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/28/2015 14:46'!
testMap
	self assert: (self materialize: '{#foo:1}') = (STON mapClass new at: #foo put: 1; yourself).
	self assert: (self materialize: '{}') = STON mapClass new! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 12/23/2015 19:25'!
testMetaclass
	self assert: (self materialize: 'Metaclass[#Point]') equals: Point class! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/7/2012 13:53'!
testMultiple
	| reader |
	reader := STON reader 
		on: '123 -123 nil #foo true [ 0 ] false { #one : 1 }' readStream.
	self deny: reader atEnd.
	self assert: reader next equals: 123. 
	self assert: reader next equals: -123. 
	self assert: reader next equals: nil. 
	self assert: reader next equals: #foo. 
	self assert: reader next equals: true. 
	self assert: reader next equals: { 0 }. 
	self assert: reader next equals: false. 
	self assert: reader next equals: (Dictionary with: #one -> 1). 
	self assert: reader atEnd.
! !

!STONReaderTests methodsFor: 'tests' stamp: 'dkh 4/29/2012 08:48:15'!
testNewSymbol
	| n notASymbol shouldBeSymbol |
	
	"Find a name that has not yet been interned"
	n := 0.
	[ Symbol hasInterned: (notASymbol := 'notASymbol', n printString) ifTrue: [ :symbol | symbol ] ] 
		whileTrue: [ n := n + 1 ].
	"Parsing the new, not yet interned name should create a new Symbol"
	shouldBeSymbol := self materialize: '#', notASymbol.
	self assert: (shouldBeSymbol isSymbol and: [ notASymbol = shouldBeSymbol asString ])
! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/28/2015 14:21'!
testNil
	self assert: (self materialize: 'nil') isNil! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/24/2016 20:08'!
testNonBMPCharacterDecoding
	"Characters not in the Basic Multilingual Plane are encoded as a UTF-16 surrogate pair"

	| string object |
	string := String with: 16r1D11E asCharacter. "MUSICAL SYMBOL G CLEF"
	object := (STON fromString: '''\uD834\uDD1E''').
	self assert: object equals: string! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/28/2015 14:21'!
testNull
	self assert: (self materialize: 'null') isNil! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/17/2012 21:45'!
testObject
	self assert: (self materialize: 'Point[1,2]') = (1@2).
	self assert: (self materialize: 'Point[1.5,-0.5]') = (1.5 @ -0.5).! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/23/2012 12:30'!
testOrderedCollection
	| collection |
	collection := OrderedCollection with: 1 with: 2 with: 3.
	self assert: (self materialize: 'OrderedCollection[1,2,3]') = collection.
	self assert: (self materialize: 'OrderedCollection[]') = OrderedCollection new.! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/7/2012 20:30'!
testPoint
	self assert: (self materialize: 'Point[1,2]') = (1@2)! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/5/2012 20:12'!
testReferenceCycle
	| array |
	array := (self materialize: '[1,@1]').
	self assert: array class = STON listClass.
	self assert: array size = 2.
	self assert: array first = 1.
	self assert: array second == array! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/5/2012 20:13'!
testReferenceSharing
	| one array |
	one := { #one }.
	array := (self materialize: '[[#one],@2,@2]').
	self assert: array = (STON listClass with: one with: one with: one).
	self assert: array first == array second.
	self assert: array first == array third! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/14/2016 13:19'!
testSetWithIndirectReferenceElements
	| elementsCollection set ston object |
	elementsCollection := OrderedCollection streamContents: [ :out |
		10 timesRepeat: [ out nextPut: UUID new ] ].
	set := Set withAll: (elementsCollection collect: [ :each | Array with: each ]).
	object := Array with: elementsCollection with: set.
	ston := STON toStringPretty: object.
	object := STON fromString: ston readStream.
	object first do: [ :each |
		self assert: (object second includes: (Array with: each)) ].
	self assert: object second isHealthy ! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/14/2016 13:14'!
testSetWithReferenceElements
	| elementsCollection set ston object |
	elementsCollection := OrderedCollection streamContents: [ :out |
		10 timesRepeat: [ out nextPut: UUID new ] ].
	set := Set withAll: elementsCollection.
	object := Array with: elementsCollection with: set.
	ston := STON toStringPretty: object.
	object := STON fromString: ston readStream.
	object first do: [ :each |
		self assert: (object second includes: each) ].
	self assert: object second isHealthy ! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/7/2012 13:53'!
testStreaming
	| reader |
	reader := STON reader 
		on: '1 2 3 4 5 6 7 8 9 10' readStream.
	self 
		assert: (Array streamContents: [ :stream |
			[ reader atEnd] whileFalse: [ 
				stream nextPut: reader next ] ]) sum
		equals: #(1 2 3 4 5 6 7 8 9 10) sum! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 11/19/2016 21:30'!
testString
	| string |
	self assert: (self materialize: '''foo''') = 'foo'.
	self assert: (self materialize: '''FOO''') = 'FOO'.
	self assert: (self materialize: '''\u00E9l\u00E8ve en Fran\u00E7ais''') = 'élève en Français'.
	string := String withAll: { 
		$". $'. $\. $/. Character tab. Character cr. Character lf.  Character newPage. Character backspace }.
	self assert: (self materialize: '''\"\''\\\/\t\r\n\f\b''') = string.
! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/28/2015 14:47'!
testSymbol
	self assert: (self materialize: '#''foo''') = #foo.
	self assert: (self materialize: '#foo') = #foo! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 11/19/2016 22:04'!
testTime
	| time |
	time := Time hour: 6 minute: 30 second: 15.
	self assert: (self materialize: 'Time[''06:30:15'']') equals: time.
	time := Time hour: 6 minute: 30 second: 15 nanoSecond: 123.
	self assert: (self materialize: 'Time[''06:30:15.000000123'']') equals: time.
! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 8/12/2014 15:11'!
testUnknownClasses
	| input object |
	input := 'FooBar { #foo : 1, #bar : true }'.
	self should: [ self materialize: input ] raise: STONReaderError.
	object := STON reader 
		acceptUnknownClasses: true; 
		on: input readStream; 
		next.
	self assert: object class equals: STON mapClass.
	self assert: (object at: #foo) equals: 1.
	self assert: (object at: #bar).
	self assert: (object at: STON classNameKey) equals: #FooBar! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/23/2012 16:13'!
testUser
	| user |
	(user := STONTestUser new)
		username: 'john@foo.com';
		password: 'secret1'.
	self assert: (self materialize: 'STONTestUser{#username:''john@foo.com'',#password:''secret1'',#enabled:true}') = user! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/7/2012 20:48'!
testUser2
	| user |
	(user := STONTestUser2 new)
		username: 'john@foo.com';
		password: 'secret1'.
	self assert: (self materialize: 'STONTestUser2{#username:''john@foo.com'',#password:''secret1'',#enabled:true}') = user! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/7/2012 13:39'!
testWhitespace
	| whitespace |
	whitespace := { Character space. Character tab. Character cr. Character lf }.
	self assert: (self materialize: whitespace, '123') = 123
	! !

TestCase subclass: #STONTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONTests commentStamp: '<historical>' prior: 0!
STONTests tests the API offered by STON.
!

!STONTests class methodsFor: 'utilities' stamp: 'SvenVanCaekenberghe 11/30/2012 20:04'!
fastReadFromFileNamed: path
	^ path asFileReference
		readStreamDo: [ :stream | 
			STON reader
				on: (ZnBufferedReadStream on: stream);
				optimizeForLargeStructures;
				next ]! !

!STONTests class methodsFor: 'utilities' stamp: 'SvenVanCaekenberghe 11/29/2012 22:51'!
fastWrite: object toFileNamed: path
	^ path asFileReference
		writeStreamDo: [ :fileStream | 
			ZnBufferedWriteStream
				on: fileStream
				do: [ :stream | 
					STON writer
						on: stream;
						optimizeForLargeStructures;
						nextPut: object ] ]! !

!STONTests class methodsFor: 'utilities' stamp: 'SvenVanCaekenberghe 11/29/2012 22:27'!
readFromFileNamed: path
	^ path asFileReference
		readStreamDo: [ :stream | 
			STON reader
				on: stream;
				next ]! !

!STONTests class methodsFor: 'utilities' stamp: 'SvenVanCaekenberghe 11/29/2012 22:28'!
write: object toFileNamed: path
	^ path asFileReference
		writeStreamDo: [ :stream | 
			STON writer
				on: stream;
				nextPut: object ]! !

!STONTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 09:53'!
testFromString
	| object |
	object := STON listClass withAll: { 1. 0. -1. true. false. nil }.
	self assert: (STON fromString: '[1,0,-1,true,false,nil]') = object! !

!STONTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 6/9/2015 10:09'!
testFromStringWithComments
	| object |
	object := STON listClass withAll: { 1. 0. -1. true. false. nil }.
	self 
		assert: (STON fromStringWithComments: '// comment\[1, /* comment */ 0, -1, true, false, nil] // comment' withCRs)
		equals: object! !

!STONTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/12/2012 20:20'!
testPrettyPrinting
	| object |
	object := STONTestUser dummy.
	self assert: (STON fromString: (STON toStringPretty: object)) = object.
	object := STONTestDomainObject dummy.
	self assert: (STON fromString: (STON toStringPretty: object)) = object! !

!STONTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 11/29/2012 10:32'!
testRoomExitCycles
	| model room1 room2 exit1 exit2 ston object |
	(room1 := STONTestMap new) at: #name put: 'Room 1'.
	(room2 := STONTestMap new) at: #name put: 'Room 2'.
	(exit1 := STONTestMap new)
		at: #name put: 'Exit 1';
		at: #origin put: room1;
		at: #destination put: room2.
	(exit2 := STONTestMap new)
		at: #name put: 'Exit 2';
		at: #origin put: room2;
		at: #destination put: room1.
	room1 at: #exit put: exit1.
	room2 at: #exit put: exit2.
	model := Array with: room1 with: room2.
	ston := STON toString: model.
	object := STON fromString: ston.
	"We can't just compare because this is a recursive datastructure"
	self assert: (object first at: #name) equals: 'Room 1'.
	self assert: (object second at: #name) equals: 'Room 2'.
	self assert: ((object first at: #exit) at: #name) equals: 'Exit 1'.
	self assert: ((object second at: #exit) at: #name) equals: 'Exit 2'.
	self assert: ((object first at: #exit) at: #origin) == object first.
	self assert: ((object first at: #exit) at: #destination) == object second.
	self assert: ((object second at: #exit) at: #origin) == object second.
	self assert: ((object second at: #exit) at: #destination) == object first.
	"Try writing again the parse model" 
	self assert: (STON toString: object) equals: ston! !

!STONTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 09:53'!
testToString
	| object |
	object := STON listClass withAll: { 1. 0. -1. true. false. nil }.
	self assert: (STON toString: object) = '[1,0,-1,true,false,nil]'! !

TestCase subclass: #STONWriteReadTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONWriteReadTests commentStamp: '<historical>' prior: 0!
STONWriteReadTests test serialization followed by materialization.!

STONWriteReadTests subclass: #STONLargeWriteReadTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONLargeWriteReadTests commentStamp: '<historical>' prior: 0!
STONLargeWriteReadTests test the optimalizations for large structures.!

!STONLargeWriteReadTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 11/29/2012 15:13'!
materialize: string
	^ STON reader
		on: string readStream;
		optimizeForLargeStructures;
		next! !

!STONLargeWriteReadTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 6/9/2015 10:15'!
serialize: anObject
	^ String streamContents: [ :stream |
		STON writer 
			on: stream; 
			optimizeForLargeStructures; 
			nextPut: anObject ]! !

!STONLargeWriteReadTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 11/29/2012 15:12'!
serializeJson: anObject
	^ String streamContents: [ :stream |
		STON jsonWriter 
			on: stream; 
			prettyPrint: true;
			optimizeForLargeStructures; 
			nextPut: anObject ]! !

STONWriteReadTests subclass: #STONWriteAsciiOnlyReadTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONWriteAsciiOnlyReadTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 2/24/2016 21:20'!
serialize: anObject
	^ String streamContents: [ :stream |
		STON writer 
			on: stream; 
			asciiOnly: true;
			nextPut: anObject ]! !

!STONWriteAsciiOnlyReadTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 2/24/2016 21:20'!
serializeJson: anObject
	^ String streamContents: [ :stream |
		STON jsonWriter 
			on: stream; 
			asciiOnly: true;
			nextPut: anObject ]! !

STONWriteReadTests subclass: #STONWritePrettyPrinterReadTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONWritePrettyPrinterReadTests commentStamp: '<historical>' prior: 0!
STONWritePrettyPrinterReadTests tests pretty printed serialization followed by materialization.!

!STONWritePrettyPrinterReadTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/5/2012 20:03'!
serialize: anObject
	^ String streamContents: [ :stream |
		STON writer 
			on: stream; 
			prettyPrint: true;
			nextPut: anObject ]! !

!STONWritePrettyPrinterReadTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/15/2012 09:33'!
serializeJson: anObject
	^ String streamContents: [ :stream |
		STON jsonWriter 
			on: stream; 
			prettyPrint: true;
			nextPut: anObject ]! !

STONWriteReadTests subclass: #STONWriteReadCommentsTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONWriteReadCommentsTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 6/9/2015 10:12'!
materialize: string
	^ STON reader
		on: (STONCStyleCommentsSkipStream on: string readStream);
		optimizeForLargeStructures;
		next! !

!STONWriteReadCommentsTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 6/9/2015 10:16'!
serialize: anObject
	^ String streamContents: [ :stream |
		stream << '/* initial comment */'.
		STON writer 
			on: stream;
			nextPut: anObject.
		stream << '/* final comment */' ]! !

!STONWriteReadTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/5/2012 20:03'!
materialize: string
	^ STON reader 
		on: string readStream;
		next! !

!STONWriteReadTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/5/2012 20:04'!
serialize: anObject
	^ String streamContents: [ :stream |
		STON writer 
			on: stream;
			nextPut: anObject ]! !

!STONWriteReadTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/5/2012 19:55'!
serializeAndMaterialize: object
	| serialization materialization |
	serialization := self serialize: object.
	materialization := self materialize: serialization.
	self assert: object equals: materialization
	! !

!STONWriteReadTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/5/2012 19:55'!
serializeAndMaterializeJsonMode: object
	| serialization materialization |
	serialization := self serializeJson: object.
	materialization := self materialize: serialization.
	self assert: object equals: materialization
! !

!STONWriteReadTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/15/2012 09:33'!
serializeJson: anObject
	^ String streamContents: [ :stream |
		STON jsonWriter 
			on: stream;
			nextPut: anObject ]! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/8/2012 14:23'!
testAssociations
	| associations |
	associations := OrderedCollection new.
	1 to: 10 do: [ :each |
		associations add: each -> each printString ].
	self serializeAndMaterialize: associations! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/8/2012 14:58'!
testCharacters
	| characters |
	characters := STON listClass withAll: ($a to: $z), ($A to: $Z).
	self serializeAndMaterialize: characters! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 12/23/2015 18:52'!
testClasses
	| classes |
	classes := STON listClass withAll: { Point. Integer. Object }.
	self serializeAndMaterialize: classes.
	classes := STON listClass withAll: { Point class. Integer class. Object class }.
	self serializeAndMaterialize: classes.
	classes := STON listClass withAll: { Class. Metaclass. Class class. Point class class }.
	self serializeAndMaterialize: classes.! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'dkh 4/29/2012 08:48:15'!
testCollections
	| collections |
	collections := STON listClass withAll: {
		#(1 2 3).
		OrderedCollection withAll: #(1 2 3).
		Set withAll: #(1 2 3).
		IdentitySet withAll: #(1 2 3).
		Bag withAll: #(1 2 2 3).
		Dictionary new at: 1 put: 1; at: 2 put: 2; yourself.
		IdentityDictionary new at: 1 put: 1; at: 2 put: 2; yourself.
		#[1 2 3].
		#(1 2 3) asIntegerArray.
		#(1 2 3) asFloatArray }.
	self serializeAndMaterialize: collections! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 8/15/2015 17:03'!
testCustomAssociations
	| associations |
	associations := OrderedCollection new.
	associations add: #foo->100.
	associations add: (STONTestAssociation key: #foo value:100).
	self serializeAndMaterialize: associations! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 11/19/2016 21:38'!
testDatesAndTimes
	| datesAndTimes |
	datesAndTimes := STON listClass withAll: { 
		Time now. 
		Date today. 
		DateAndTime now }.
	self serializeAndMaterialize: datesAndTimes
! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/10/2012 20:53'!
testDomainObject
	| object objects |
	object := STONTestDomainObject dummy.
	self serializeAndMaterialize: object.
	objects := STON listClass streamContents: [ :stream |
		10 timesRepeat: [ stream nextPut: STONTestDomainObject dummy ] ].
	self serializeAndMaterialize: objects.
	objects := STON mapClass new.
	10 timesRepeat: [ | newObject |
		newObject := STONTestDomainObject dummy.
		objects at: newObject integer put: newObject ].
	self serializeAndMaterialize: objects.! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 10:17'!
testEmpty
	| empty |
	empty := STON listClass new.
	self serializeAndMaterialize: empty.
	empty := STON mapClass new.
	self serializeAndMaterialize: empty.! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/7/2016 23:35'!
testFileSystemSupport
	| fileReferences fileLocators |
	fileReferences := STON listClass withAll: { 
		FileLocator image asFileReference.
		FileLocator workingDirectory asFileReference.
		(FileLocator home / 'foo.txt') asFileReference }.
	self serializeAndMaterialize: fileReferences.
	fileLocators := STON listClass withAll: { 
		FileLocator image.
		FileLocator workingDirectory.
		FileLocator home / 'foo.txt' }.
	self serializeAndMaterialize: fileLocators.! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/5/2012 19:58'!
testFloats
	| floats serialization materialization |
	floats := STON listClass withAll: ((-10 to: 10) collect: [ :each | each * Float pi ]).
	serialization := self serialize: floats.
	materialization := self materialize: serialization.
	self assert: floats size = materialization size.
	1 to: floats size do: [:index | | float |
		float := floats at: index.
		"Use #closeTo: instead of #= to increase portability"
		self assert: (float closeTo: (materialization at: index)) ]! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/24/2016 14:00'!
testIntervals
	| intervals |
	intervals := STON listClass withAll: { 
		1 to: 10.
		1 to: 10 by: 2.
		100 to: 50 by: -5 }.
	self serializeAndMaterialize: intervals! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'dkh 4/29/2012 08:48:15'!
testJsonMode
	| object |
	object := STON listClass withAll: {
		Float pi.
		'Hello World'.
		true.
		nil.
		STON listClass withAll: #( 1 2 3) asByteArray.
		STON mapClass new 
			at: 'x' put: 1; 
			at: 'y' put: 2; 
			yourself 
	}.
	self serializeAndMaterializeJsonMode: object
! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/10/2015 20:22'!
testOrderedDictionary
	"OrderedDictionary is special because it does not inherit from Dictionary.
	It might also not exist in some dialects, where this test could be skipped."
	
	| dictionaries orderedDictionaryClass orderedIdentityDictionaryClass |
	orderedDictionaryClass := Smalltalk at: #OrderedDictionary ifAbsent: [ Dictionary ].
	orderedIdentityDictionaryClass := Smalltalk at: #OrderedIdentityDictionary ifAbsent: [ IdentityDictionary ].
	dictionaries := STON listClass withAll: {
		orderedDictionaryClass new at: 1 put: 1; at: 2 put: 2; yourself.
		orderedDictionaryClass new at: #a put: 1; at: #b put: -2; at: #c put: 0; yourself.
		orderedDictionaryClass new.
		orderedIdentityDictionaryClass new at: 1 put: 1; at: 2 put: 2; yourself.
		orderedIdentityDictionaryClass new at: #a put: 1; at: #b put: -2; at: #c put: 0; yourself.
		orderedIdentityDictionaryClass new }.
	self serializeAndMaterialize: dictionaries! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 10:16'!
testPrimitives
	| primitives |
	primitives := STON listClass withAll: { true. false. nil }.
	self serializeAndMaterialize: primitives! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/10/2015 20:21'!
testSmallDictionary
	"SmallDictionary is special because it does not inherit from Dictionary.
	It might also not exist in some dialects, where this test could be skipped."
	
	| dictionaries smallDictionaryClass |
	smallDictionaryClass := Smalltalk at: #SmallDictionary ifAbsent: [ Dictionary ].
	dictionaries := STON listClass withAll: {
		smallDictionaryClass new at: 1 put: 1; at: 2 put: 2; yourself.
		smallDictionaryClass new at: 1 put: 1; at: 2 put: 2; yourself.
		smallDictionaryClass new }.
	self serializeAndMaterialize: dictionaries! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 10:17'!
testSmallIntegers
	| integers |
	integers := STON listClass withAll: (-10 to: 10).
	self serializeAndMaterialize: integers! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 11/19/2016 21:39'!
testSpecialCharacters
	| primitives |
	primitives := STON listClass withAll: { 
		String withAll: { Character tab. Character lf. Character cr }.
		String withAll: { $'. $". $\. $/ }.
		'élèves français'.
		'Düsseldorf Königsallee'.
		#(1 10 20 30 127 140 150 160 200 255) collect: #asCharacter as: String }.
	self serializeAndMaterialize: primitives! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/23/2012 12:23'!
testStrings
	| strings |
	strings := Collection allSubclasses collect: [ :each | each name asString ].
	self serializeAndMaterialize: strings! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/15/2014 13:36'!
testSymbols
	| symbols |
	self serializeAndMaterialize: #( #bytes #'' ).
	symbols := Collection allSubclasses collect: [ :each | each name ].
	self serializeAndMaterialize: symbols
! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 3/24/2014 13:23'!
testTextAndRunArray
	| texts |
	texts := { 
		'Text!!' asText. 
		(Text string: 'I am bold' attribute: TextEmphasis bold), ' and I am normal text'.
		Text new }.
	self serializeAndMaterialize: texts! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 10:17'!
testUser
	| user users |
	user := STONTestUser dummy.
	self serializeAndMaterialize: user.
	users := STON listClass streamContents: [ :stream |
		10 timesRepeat: [ stream nextPut: STONTestUser dummy ] ].
	self serializeAndMaterialize: users.
	users := STON mapClass new.
	10 timesRepeat: [ | newUser |
		newUser := STONTestUser dummy.
		users at: newUser username put: newUser ].
	self serializeAndMaterialize: users.! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/7/2012 20:48'!
testUser2
	| user users |
	user := STONTestUser2 dummy.
	self serializeAndMaterialize: user.
	users := STON listClass streamContents: [ :stream |
		10 timesRepeat: [ stream nextPut: STONTestUser2 dummy ] ].
	self serializeAndMaterialize: users.
	users := STON mapClass new.
	10 timesRepeat: [ | newUser |
		newUser := STONTestUser2 dummy.
		users at: newUser username put: newUser ].
	self serializeAndMaterialize: users.! !

TestCase subclass: #STONWriterTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONWriterTests commentStamp: 'SvenVanCaekenberghe 1/22/2012 20:14' prior: 0!
STONWriterTests test serialization.!

!STONWriterTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/5/2012 20:06'!
serialize: anObject
	^ String streamContents: [ :stream |
		STON writer 
			on: stream;
			nextPut: anObject ]! !

!STONWriterTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 7/2/2015 15:24'!
serializeAsciiOnly: anObject
	^ String streamContents: [ :stream |
		STON writer 
			on: stream;
			asciiOnly: true;
			nextPut: anObject ]! !

!STONWriterTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/15/2012 09:33'!
serializeJson: anObject
	^ String streamContents: [ :stream |
		STON jsonWriter 
			on: stream; 
			nextPut: anObject ]! !

!STONWriterTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/5/2012 20:05'!
serializePretty: anObject
	^ String streamContents: [ :stream |
		STON writer 
			on: stream; 
			prettyPrint: true;
			nextPut: anObject ]! !

!STONWriterTests methodsFor: 'tests' stamp: 'ChristopheDemarey 11/6/2014 15:14'!
testAssociation
	self assert: (self serialize: 'foo' -> 1) =  '''foo'':1'.
	self assert: (self serialize: #bar -> 2) =  '#bar:2'.
	self assert: (self serialize: 'foo bar' -> #ok) =  '''foo bar'':#ok'.
	self assert: (self serialize: 123 -> 456) =  '123:456'
! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/14/2012 15:50'!
testBoolean
	self assert: (self serialize: true) = 'true'.
	self assert: (self serialize: false) = 'false'! !

!STONWriterTests methodsFor: 'tests' stamp: 'dkh 4/29/2012 08:48:15'!
testByteArray
	self assert: (self serialize: #(1 2 3) asByteArray) = 'ByteArray[''010203'']' 
! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 12/23/2015 19:24'!
testClass
	self assert: (self serialize: Point) = 'Class[#Point]'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 3/7/2013 10:52'!
testCustomNewline
	| output |
	output := String streamContents: [ :out |
		(STON writer on: out)
			newLine: String lf;
			prettyPrint: true;
			nextPut: #( 1 ) ].
	self 
		assert: output 
		equals: ('[\	1\]' withCRs replaceAll: Character cr with: Character lf)! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/23/2012 09:33'!
testDate
	| date |
	date := Date year: 2012 month: 1 day: 1.
	self assert: (self serialize: date) = 'Date[''2012-01-01'']'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/19/2012 10:00'!
testDateAndTime
	| dateAndTime |
	dateAndTime := DateAndTime year: 2012 month: 1 day: 1 hour: 6 minute: 30 second: 15 offset: 1 hour.
	self assert: (self serialize: dateAndTime) = 'DateAndTime[''2012-01-01T06:30:15+01:00'']'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/5/2012 20:15'!
testDictionary
	| collection |
	collection := STON mapClass new at: 1 put: 1; at: 2 put: 2; yourself.
	self assert: (self serialize: collection) = '{1:1,2:2}'.
	self assert: (self serialize: STON mapClass new) = '{}'.! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 10/25/2012 15:37'!
testDictionaryWithComplexKeys
	| collection |
	collection := STON mapClass new at: true put: 1; at: #(foo) put: 2; yourself.
	self assert: (self serialize: collection) = '{true:1,[#foo]:2}'.! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 11/19/2016 21:31'!
testDoubleQuotedString
	| string |
	self assert: (self serializeJson: 'foo') = '"foo"'.
	self assert: (self serializeJson: 'FOO') = '"FOO"'.
	self assert: (self serializeJson: 'élève en Français') = '"élève en Français"'.
	string := String withAll: { 
		$". $'. $\. $/. Character tab. Character cr. Character lf. Character newPage. Character backspace }.
	"Note that in JSON mode, double quotes get escaped, and single quotes not"
	self assert: (self serializeJson: string) equals: '"\"''\\\/\t\r\n\f\b"'.
! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/5/2012 19:09'!
testEmptyArrayPretty
	self assert: (self serializePretty: STON listClass new) equals: '[ ]' ! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/5/2012 19:09'!
testEmptyDictionaryPretty
	self assert: (self serializePretty: STON mapClass new) equals: '{ }' ! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/3/2012 20:56'!
testFloat
	self assert: (self serialize: 1.5) = '1.5'.
	self assert: (self serialize: 0.0) = '0.0'.
	self assert: (self serialize: -1.5) = '-1.5'.
	self assert: ((self serialize: Float pi) beginsWith:  '3.14159').
	self assert: ((self serialize: 1/3) beginsWith:  '0.333').
	self assert: (self serialize: (10 raisedTo: 100) asFloat) = '1.0e100'.
	self assert: (self serialize: (10 raisedTo: -50) asFloat) = '1.0e-50'.
	self assert: (self serialize: (10 raisedTo: -50) asFloat negated) = '-1.0e-50'.! !

!STONWriterTests methodsFor: 'tests' stamp: 'dkh 4/29/2012 08:48:15'!
testIdentityDictionary
	| collection |
	collection := IdentityDictionary new at: 1 put: 1; at: 2 put: 2; yourself.
	self assert: (self serialize: collection) = 'IdentityDictionary{1:1,2:2}'.
	self assert: (self serialize: IdentityDictionary new) = 'IdentityDictionary{}'.! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/14/2012 15:50'!
testInteger
	self assert: (self serialize: 1) = '1'.
	self assert: (self serialize: 0) = '0'.
	self assert: (self serialize: -1) = '-1'.
	self assert: (self serialize: 1234567890) = '1234567890'.
	self assert: (self serialize: -1234567890) = '-1234567890'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/5/2012 20:06'!
testIsSimpleSymbol
	self assert: (STON writer isSimpleSymbol: #foo).
	self assert: (STON writer isSimpleSymbol: #az).
	self assert: (STON writer isSimpleSymbol: #AZ).
	self assert: (STON writer isSimpleSymbol: #N0123456789).
	self assert: (STON writer isSimpleSymbol: #foo123).
	self assert: (STON writer isSimpleSymbol: #'Foo/Bar').
	self assert: (STON writer isSimpleSymbol: #'Foo.Bar').
	self assert: (STON writer isSimpleSymbol: #'Foo-Bar').
	self assert: (STON writer isSimpleSymbol: #'Foo_Bar').
	self assert: (STON writer isSimpleSymbol: #foo).
	self deny: (STON writer isSimpleSymbol: #'#^&$%')! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/26/2015 23:23'!
testKeepingNewLines
	| input result output |
	input := 'line ending with CR', String cr, 
		'line ending with LF', String lf, 
		'line ending with CRLF', String crlf.
	output := '''line ending with CR', String crlf, 
		'line ending with LF', String crlf, 
		'line ending with CRLF', String crlf, ''''.
	result := String streamContents: [ :out |
		(STON writer on: out) newLine: String crlf; keepNewLines: true; nextPut: input ].
	self assert: result equals: output.
	output := '''line ending with CR', String cr, 
		'line ending with LF', String cr, 
		'line ending with CRLF', String cr, ''''.
	result := String streamContents: [ :out |
		(STON writer on: out) newLine: String cr; keepNewLines: true; nextPut: input ].
	self assert: result equals: output! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 10:21'!
testList
	self assert: (self serialize: (STON listClass withAll: #(1 2 3))) = '[1,2,3]'.
	self assert: (self serialize: STON listClass new) = '[]'.
	self assert: (self serialize: (STON listClass withAll: { 1. -1. 0. #foo. 'a b c'. true. false. nil })) = '[1,-1,0,#foo,''a b c'',true,false,nil]'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 10:20'!
testMap
	| map |
	(map := STON mapClass new)
		at: #foo put: 1;
		at: #bar put: 2.
	self assert: (self serialize: map) = '{#foo:1,#bar:2}'.
	self assert: (self serialize: STON mapClass new) = '{}'.
	map removeAll.
	map at: 'foo bar' put: #ok.
	self assert: (self serialize: map) = '{''foo bar'':#ok}'.
	map removeAll.
	map at: 123 put: 456.
	self assert: (self serialize: map) = '{123:456}'.

! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 12/23/2015 19:24'!
testMetaclass
	self assert: (self serialize: Point class) = 'Metaclass[#Point]'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/14/2012 20:20'!
testNil
	self assert: (self serialize: nil) = 'nil'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/24/2016 20:09'!
testNonBMPCharacterEncoding
	"Characters not in the Basic Multilingual Plane are encoded as a UTF-16 surrogate pair"

	| string json |
	string := String with: 16r1D11E asCharacter. "MUSICAL SYMBOL G CLEF"
	json := String streamContents: [ :out |
		(STON writer on: out) asciiOnly: true; nextPut: string ].
	self assert: json equals: '''\uD834\uDD1E'''! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/5/2012 19:10'!
testNull
	self assert: (self serializeJson: nil) equals: 'null'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/23/2012 12:28'!
testOrderedCollection
	| collection |
	collection := OrderedCollection with: 1 with: 2 with: 3.
	self assert: (self serialize: collection) = 'OrderedCollection[1,2,3]'.
	self assert: (self serialize: OrderedCollection new) = 'OrderedCollection[]'.! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/14/2012 20:35'!
testPoint
	self assert: (self serialize: 1@2) = 'Point[1,2]'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 10:22'!
testReferenceCycle
	| array |
	array := STON listClass with: 1 with: nil.
	array at: 2 put: array.
	self assert: (self serialize: array) = '[1,@1]'.! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/29/2012 21:53'!
testReferenceSharing
	| array one |
	one := { #one }.
	array := STON listClass with: one with: one with: one.
	self assert: (self serialize: array) = '[[#one],@2,@2]'.! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/5/2012 20:07'!
testReferenceSharingError
	| serializer array one |
	serializer := [ :object | 
		String streamContents: [ :stream |
			STON writer 
				on: stream;
				referencePolicy: #error; 
				nextPut: object ] ].
	one := { #one }.
	array := STON listClass with: one with: one with: one.
	self 
		should: [ (serializer value: array) = '[[#one],[#one],[#one]]' ] 
		raise: STONWriterError
! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/5/2012 20:07'!
testReferenceSharingIgnore
	| serializer array one |
	serializer := [ :object | 
		String streamContents: [ :stream |
			STON writer 
				on: stream;
				referencePolicy: #ignore; 
				nextPut: object ] ].
	one := { #one }.
	array := STON listClass with: one with: one with: one.
	self assert: (serializer value: array) = '[[#one],[#one],[#one]]'.! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 6/6/2016 10:21'!
testRestrictedClassesInJsonMode
	self should: [ self serializeJson: 1@2 ] raise: STONWriterError.
	self should: [ self serializeJson: #foo->100 ] raise: STONWriterError.
	self should: [ self serializeJson: STONTestUser dummy ] raise: STONWriterError.
! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 11/19/2016 21:32'!
testString
	| string |
	self assert: (self serialize: 'foo') = '''foo'''.
	self assert: (self serialize: 'FOO') = '''FOO'''.
	self assert: (self serializeAsciiOnly: 'élève en Français') = '''\u00E9l\u00E8ve en Fran\u00E7ais'''.
	self assert: (self serialize: 'élève en Français') = '''élève en Français'''.
	string := String withAll: { 
		$". $'. $\. $/. Character tab. Character cr. Character lf.  Character newPage. Character backspace }.
	self assert: (self serialize: string) equals: '''\"\''\\\/\t\r\n\f\b'''.
! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/14/2012 17:07'!
testSymbol
	self assert: (self serialize: #foo) = '#foo'.
	self assert: (self serialize: #FOO) = '#FOO'.
	self assert: (self serialize: #bytes) = '#bytes'.
	self assert: (self serialize: #'foo.bar') = '#foo.bar'.
	self assert: (self serialize: #'foo-bar') = '#foo-bar'.
	self assert: (self serialize: #'foo_bar') = '#foo_bar'.
	self assert: (self serialize: #'foo/bar') = '#foo/bar'.
	self assert: (self serialize: #'foo bar') = '#''foo bar'''.
	self assert: (self serialize: #foo123) = '#foo123'.! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/5/2012 19:12'!
testSymbolAsString
	self assert: (self serializeJson: #foo) = '"foo"'.
	self assert: (self serializeJson: #'FOO') = '"FOO"'.
! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 11/19/2016 22:05'!
testTime
	| time |
	time := Time hour: 6 minute: 30 second: 15.
	self assert: (self serialize: time) equals: 'Time[''06:30:15'']'.
	time := Time hour: 6 minute: 30 second: 15 nanoSecond: 123.
	self assert: (self serialize: time) equals: 'Time[''06:30:15.000000123'']'.
! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 11/13/2013 23:58'!
testUser
	| user |
	(user := STONTestUser new)
		username: 'john@foo.com';
		password: 'secret1'.
	self 
		assert: (self serialize: user)
		equals: 'TestUser{#username:''john@foo.com'',#password:''secret1'',#enabled:true}'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 11/13/2013 23:58'!
testUser2
	| user |
	(user := STONTestUser2 new)
		username: 'john@foo.com';
		password: 'secret1'.
	self 
		assert: (self serialize: user)
		equals: 'TestUser2{#username:''john@foo.com'',#password:''secret1'',#enabled:true}'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 11/13/2013 23:56'!
testUser3Nil
	| user |
	user := STONTestUser3 new.
	self 
		assert: (self serialize: user) 
		equals: 'TestUser3{#username:nil,#password:nil,#enabled:true}'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 11/13/2013 23:56'!
testUserNil
	| user |
	user := STONTestUser new.
	self assert: (self serialize: user) equals: 'TestUser{#enabled:true}'! !

Association subclass: #STONTestAssociation
	instanceVariableNames: 'timestamp'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONTestAssociation commentStamp: 'SvenVanCaekenberghe 8/15/2015 16:59' prior: 0!
STONTestAssociation is used to support unit tests.
!

!STONTestAssociation methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 8/15/2015 17:04'!
key: aKey value: anObject 
	super key: aKey value: anObject.
	timestamp := self now! !

!STONTestAssociation methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 8/15/2015 17:05'!
now
	^ DateAndTime now! !

!STONTestAssociation methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 8/15/2015 17:01'!
timestamp
	^ timestamp! !

!STONTestAssociation methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 8/15/2015 17:04'!
value: anObject
	super value: anObject.
	timestamp := self now! !

Dictionary subclass: #STONTestMap
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONTestMap commentStamp: '<historical>' prior: 0!
STONTestMap is used to support unit tests.

I am a Dictionary but I don't print my elements during #printOn: to allow safe inspection of structures containing cycles that would otherwise lead to infinite loops.!

!STONTestMap class methodsFor: 'instance creation' stamp: 'SvenVanCaekenberghe 11/29/2012 22:34'!
classTree
	^ self classTree: Object! !

!STONTestMap class methodsFor: 'instance creation' stamp: 'SvenVanCaekenberghe 11/29/2012 22:35'!
classTree: topClass
	| map |
	map := IdentityDictionary new.
	topClass withAllSubclasses do: [ :eachClass | | info |
		(info := self new)
			at: #name put: eachClass name asString;
			at: #comment put: eachClass comment;
			at: #isMeta put: eachClass isMeta;
			at: #methods put: eachClass selectors.		
		map at: eachClass put: info ].
	map keysAndValuesDo: [ :eachClass :eachInfo |
		eachClass == topClass
			ifFalse: [ eachInfo at: #superclass put: (map at: eachClass superclass) ].
		eachInfo at: #subclasses put: (eachClass subclasses collect: [ :subClass | map at: subClass ]) ].
	^ map at: topClass! !

!STONTestMap class methodsFor: 'instance creation' stamp: 'SvenVanCaekenberghe 11/29/2012 22:34'!
classTreeExtended
	^ self classTreeExtended: Object! !

!STONTestMap class methodsFor: 'instance creation' stamp: 'SvenVanCaekenberghe 11/30/2012 08:55'!
classTreeExtended: topClass
	| map |
	map := IdentityDictionary new.
	topClass withAllSubclasses do: [ :eachClass | | info methodsInfo |
		(info := self new)
			at: #name put: eachClass name asString;
			at: #comment put: eachClass comment;
			at: #isMeta put: eachClass isMeta;
			at: #methods put: (methodsInfo := self new).
		eachClass methods do: [ :eachMethod | | methodInfo |
			(methodInfo := self new)
				at: #name put: eachMethod selector;
				at: #numArgs put: eachMethod numArgs;
				at: #class put: info.
			methodsInfo at: eachMethod selector put: methodInfo ].
		map at: eachClass put: info ].
	map keysAndValuesDo: [ :eachClass :eachInfo |
		eachClass == topClass 
			ifFalse: [ eachInfo at: #superclass put: (map at: eachClass superclass) ].
		eachInfo at: #subclasses put: (eachClass subclasses collect: [ :subClass | map at: subClass ]) ].
	^ map at: topClass! !

!STONTestMap class methodsFor: 'ston-core' stamp: 'SvenVanCaekenberghe 11/29/2012 21:18'!
stonName
	^ #TestMap! !

!STONTestMap methodsFor: 'printing' stamp: 'SvenVanCaekenberghe 11/29/2012 21:32'!
printElementsOn: stream
	stream
		nextPut: $(;
		nextPut: $#;
		print: self size;
		nextPut: $)! !

Object subclass: #STONTestDomainObject
	instanceVariableNames: 'created modified integer float description color tags bytes boolean'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONTestDomainObject commentStamp: 'SvenVanCaekenberghe 2/10/2012 20:25' prior: 0!
STONTestDomainObject is used to support unit tests.

Instance Variables
	boolean:		<Boolean>
	bytes:			<ByteArray>
	color:			<Symbol>
	created:		<DateAndTime>
	description:	<String>
	float:			<Float>
	integer:		<Integer>
	modified:	<DateAndTime>
	tags:			<Array of: Symbol>!

!STONTestDomainObject class methodsFor: 'instance creation' stamp: 'dkh 4/29/2012 08:48:15'!
dummy
	^ self new
		integer: 999999 atRandom;
		float: 999 atRandom / Float pi;
		boolean: #(true false) atRandom;
		bytes: (ByteArray streamContents: [ :out | 32 timesRepeat: [ out nextPut: 255 atRandom ] ]);
		description: (String streamContents: [ :out | 16 atRandom timesRepeat: [ out nextPutAll: 'Blah' ] ]);
		color: #(#red #green #blue) atRandom;
		tags: (Array 
			with: #(#one #two #three) atRandom
 			with: #(#alpha #beta #gamma) atRandom 
			with: #(#low #medium #high) atRandom);
		yourself
! !

!STONTestDomainObject class methodsFor: 'ston-core' stamp: 'SvenVanCaekenberghe 2/11/2012 13:15'!
stonName
	^ #TestDomainObject! !

!STONTestDomainObject methodsFor: 'comparing' stamp: 'SvenVanCaekenberghe 5/5/2012 20:00'!
= anObject
	"Answer whether the receiver and anObject represent the same object."

	self == anObject
		ifTrue: [ ^ true ].
	self class = anObject class
		ifFalse: [ ^ false ].
	^ color = anObject color
		and: [ 
			modified = anObject modified
				and: [ 
					created = anObject created
						and: [ 
							description = anObject description
								and: [ 
									boolean = anObject boolean
										and: [ 
											(float closeTo: anObject float) 		"Use #closeTo: instead of #= to increase portability"
												and: [ 
													bytes = anObject bytes 
														and: [ 
															integer = anObject integer 
																and: [ tags = anObject tags ] ] ] ] ] ] ] ]
! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
boolean
	^ boolean! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
boolean: anObject
	boolean := anObject! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
bytes
	^ bytes! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
bytes: anObject
	bytes := anObject! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
color
	^ color! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
color: anObject
	color := anObject! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
created
	^ created! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
created: anObject
	created := anObject! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
description
	^ description! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
description: anObject
	description := anObject! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
float
	^ float! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
float: anObject
	float := anObject! !

!STONTestDomainObject methodsFor: 'comparing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
hash
	"Answer an integer value that is related to the identity of the receiver."

	^ color hash
		bitXor:
			(modified hash
				bitXor:
					(created hash
						bitXor:
							(description hash
								bitXor: (boolean hash bitXor: (float hash bitXor: (bytes hash bitXor: (integer hash bitXor: tags hash)))))))! !

!STONTestDomainObject methodsFor: 'initialize-release' stamp: 'SvenVanCaekenberghe 2/10/2012 20:45'!
initialize
	created := modified := DateAndTime now.! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
integer
	^ integer! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
integer: anObject
	integer := anObject! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
modified
	^ modified! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
modified: anObject
	modified := anObject! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
tags
	^ tags! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
tags: anObject
	tags := anObject! !

Object subclass: #STONTestUser
	instanceVariableNames: 'username password enabled'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONTestUser commentStamp: '<historical>' prior: 0!
STONTestUser is used to support unit tests.

Instance Variables
	enabled:		<Boolean>
	password:	<String>
	username:	<String>
!

!STONTestUser class methodsFor: 'instance creation' stamp: 'SvenVanCaekenberghe 1/23/2012 10:10'!
dummy
	"self dummy"
	
	| username password |
	username := String streamContents: [ :stream |
		stream << 'user'; print: 999 atRandom; << '@company'; print: 99 atRandom; << '.com' ].
	password := String streamContents: [ :stream |
		stream << 'secret'; print: 999 atRandom ].
	^ self new
		username: username;
		password: password;
		yourself! !

!STONTestUser class methodsFor: 'ston-core' stamp: 'SvenVanCaekenberghe 2/11/2012 12:45'!
stonName
	^ #TestUser! !

!STONTestUser methodsFor: 'comparing' stamp: 'SvenVanCaekenberghe 1/23/2012 10:14'!
= anObject
	"Answer whether the receiver and anObject represent the same object."

	self == anObject
		ifTrue: [ ^ true ].
	self class = anObject class
		ifFalse: [ ^ false ].
	^ username = anObject username and: [ password = anObject password and: [ enabled = anObject enabled ] ]! !

!STONTestUser methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 1/23/2012 10:03'!
enabled
	^ enabled! !

!STONTestUser methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 1/23/2012 10:03'!
enabled: anObject
	enabled := anObject! !

!STONTestUser methodsFor: 'comparing' stamp: 'SvenVanCaekenberghe 1/23/2012 10:14'!
hash
	"Answer an integer value that is related to the identity of the receiver."

	^ username hash bitXor: (password hash bitXor: enabled hash)! !

!STONTestUser methodsFor: 'initialize-release' stamp: 'SvenVanCaekenberghe 1/23/2012 10:03'!
initialize 
	super initialize.
	enabled := true! !

!STONTestUser methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 1/23/2012 10:03'!
password
	^ password! !

!STONTestUser methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 1/23/2012 10:03'!
password: anObject
	password := anObject! !

!STONTestUser methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 1/23/2012 10:03'!
username
	^ username! !

!STONTestUser methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 1/23/2012 10:03'!
username: anObject
	username := anObject! !

STONTestUser subclass: #STONTestUser2
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONTestUser2 commentStamp: 'SvenVanCaekenberghe 2/10/2012 20:20' prior: 0!
STONTestUser2 extends STONTestUser with explicit implementations of #fromSton: and #stonOn:!

!STONTestUser2 class methodsFor: 'ston-core' stamp: 'SvenVanCaekenberghe 2/11/2012 13:15'!
stonName
	^ #TestUser2! !

!STONTestUser2 methodsFor: 'ston-core' stamp: 'SvenVanCaekenberghe 2/12/2012 14:32'!
fromSton: stonReader
	stonReader parseMapDo: [ :key :value |
		key = #username ifTrue: [ username := value ].
		key = #password ifTrue: [ password := value ].
		key = #enabled ifTrue: [ enabled := value ] ]
	! !

!STONTestUser2 methodsFor: 'ston-core' stamp: 'SvenVanCaekenberghe 2/7/2012 20:49'!
stonOn: stonWriter	
	stonWriter writeObject: self streamMap: [ :dictionary |
		dictionary
			at: #username put: username;
			at: #password put: password;
			at: #enabled put: enabled ]! !

STONTestUser subclass: #STONTestUser3
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONTestUser3 commentStamp: '<historical>' prior: 0!
STONTestUser3 extends STONTestUser but wants nil instance variables to be written!

!STONTestUser3 class methodsFor: 'ston-core' stamp: 'SvenVanCaekenberghe 11/27/2014 11:10'!
stonAllInstVarNames
	^ #(username password enabled)! !

!STONTestUser3 class methodsFor: 'ston-core' stamp: 'SvenVanCaekenberghe 11/13/2013 23:57'!
stonName
	^ #TestUser3! !

!STONTestUser3 methodsFor: 'ston-core' stamp: 'SvenVanCaekenberghe 11/13/2013 23:54'!
stonShouldWriteNilInstVars
	^ true! !
